@@ -65,7 +65,6 @@ editor_page_destroy (GtkObject *object)
 {
 	EditorPage *page = EDITOR_PAGE (object);
 	
-	gtk_object_destroy (GTK_OBJECT (page->priv->xml));
 	if (page->priv->gui)
 		gtk_object_destroy (GTK_OBJECT (page->priv->gui));
 	
@@ -191,7 +190,7 @@ editor_page_new_from_type (MtmEnv *env, gchar *type)
 	page->priv->entry = entry;
 	gtk_box_pack_start (GTK_BOX (glade_xml_get_widget (page->priv->xml, "file_list_hbox")), entry, TRUE, TRUE, 0);
 	
-	gtk_signal_connect (GTK_OBJECT (gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (entry))), "activate", file_changed_cb, page);
+	gtk_signal_connect (GTK_OBJECT (entry), "activate", file_changed_cb, page);
 	gtk_signal_connect (GTK_OBJECT (GTK_COMBO (gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (entry)))->list), "selection_changed", selected_cb, page);
 
 	if (!handler)
@@ -270,6 +269,15 @@ file_changed_cb (GtkWidget *item, EditorPage *page)
 	file = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (page->priv->entry), FALSE);
 	if (!file)
 		return;
+	if (!g_file_test (file, G_FILE_TEST_IS_DIR))
+	{
+		gchar *tmp = ext->handler->find (ext->handler, g_basename (file), FALSE);
+		if (!tmp)
+			tmp = ext->handler->find (ext->handler, g_basename (file), TRUE);
+		if (tmp)
+			file = tmp;
+	}
+
 	mtm_ext_set_file (ext, file);
 	g_free (file);
 }
